searchData={"content_type":"text/markdown","items":[{"doc":"","ref":"ExEtlFramework.html","title":"ExEtlFramework","type":"module"},{"doc":"","ref":"ExEtlFramework.Application.html","title":"ExEtlFramework.Application","type":"module"},{"doc":"Provides a DSL for defining ETL (Extract, Transform, Load) pipelines.\n\nThis module allows you to define a series of steps that make up your ETL process.\nIt handles the execution of these steps, including error handling and performance\nmeasurement.","ref":"ExEtlFramework.Pipeline.html","title":"ExEtlFramework.Pipeline","type":"module"},{"doc":"defmodule MyPipeline do\n      use ExEtlFramework.Pipeline\n\n      step :extract do\n        {:ok, %{data: [1, 2, 3]}}\n      end\n\n      step :transform do\n        {:ok, %{data: [2, 4, 6]}}\n      end\n\n      step :load do\n        {:ok, %{result: \"Data loaded successfully\"}}\n      end\n    end","ref":"ExEtlFramework.Pipeline.html#module-example","title":"Example - ExEtlFramework.Pipeline","type":"module"},{"doc":"Defines a step in the ETL pipeline.\n\nThis macro is used to define individual steps in your pipeline. Each step\nshould return either `{:ok, result}` or `{:error, reason}`.","ref":"ExEtlFramework.Pipeline.html#step/2","title":"ExEtlFramework.Pipeline.step/2","type":"macro"},{"doc":"- `name`: Atom that identifies the step.\n- `do`: The block of code to be executed for this step.","ref":"ExEtlFramework.Pipeline.html#step/2-parameters","title":"Parameters - ExEtlFramework.Pipeline.step/2","type":"macro"},{"doc":"step :extract do\n      {:ok, %{data: [1, 2, 3]}}\n    end","ref":"ExEtlFramework.Pipeline.html#step/2-example","title":"Example - ExEtlFramework.Pipeline.step/2","type":"macro"},{"doc":"","ref":"ExEtlFramework.Retry.html","title":"ExEtlFramework.Retry","type":"module"},{"doc":"","ref":"ExEtlFramework.Retry.html#retry_with_backoff/2","title":"ExEtlFramework.Retry.retry_with_backoff/2","type":"function"},{"doc":"Provides functions for validating data structures.\n\nThis module offers a flexible way to define validation rules and apply them\nto your data. It's particularly useful for ensuring data integrity at various\nstages of your ETL pipeline.","ref":"ExEtlFramework.Validator.html","title":"ExEtlFramework.Validator","type":"module"},{"doc":"schema = %{\n      name: [&Validator.required/1, &Validator.type(String)],\n      age: [&Validator.type(Integer)]\n    }\n    Validator.validate(%{name: \"John\", age: 30}, schema)","ref":"ExEtlFramework.Validator.html#module-example","title":"Example - ExEtlFramework.Validator","type":"module"},{"doc":"Validates that a value is not nil.","ref":"ExEtlFramework.Validator.html#required/1","title":"ExEtlFramework.Validator.required/1","type":"function"},{"doc":"- `value`: The value to check.","ref":"ExEtlFramework.Validator.html#required/1-parameters","title":"Parameters - ExEtlFramework.Validator.required/1","type":"function"},{"doc":"Returns either:\n- `:ok` if the value is not nil.\n- `{:error, \"Field is required\"}` if the value is nil.","ref":"ExEtlFramework.Validator.html#required/1-returns","title":"Returns - ExEtlFramework.Validator.required/1","type":"function"},{"doc":"Validator.required(\"Some value\")  # Returns :ok\n    Validator.required(nil)           # Returns {:error, \"Field is required\"}","ref":"ExEtlFramework.Validator.html#required/1-example","title":"Example - ExEtlFramework.Validator.required/1","type":"function"},{"doc":"Creates a validator function that checks if a value is of a specific type.","ref":"ExEtlFramework.Validator.html#type/1","title":"ExEtlFramework.Validator.type/1","type":"function"},{"doc":"- `expected_type`: The type to check against (e.g., String, Integer).","ref":"ExEtlFramework.Validator.html#type/1-parameters","title":"Parameters - ExEtlFramework.Validator.type/1","type":"function"},{"doc":"Returns a function that takes a value and returns:\n- `:ok` if the value is of the expected type or nil.\n- `{:error, reason}` if the value is not of the expected type.","ref":"ExEtlFramework.Validator.html#type/1-returns","title":"Returns - ExEtlFramework.Validator.type/1","type":"function"},{"doc":"string_validator = Validator.type(String)\n    string_validator.(\"Hello\")  # Returns :ok\n    string_validator.(123)      # Returns {:error, \"Expected type String, got 123\"}","ref":"ExEtlFramework.Validator.html#type/1-example","title":"Example - ExEtlFramework.Validator.type/1","type":"function"},{"doc":"Validates data against a given schema.","ref":"ExEtlFramework.Validator.html#validate/2","title":"ExEtlFramework.Validator.validate/2","type":"function"},{"doc":"- `data`: The data structure to validate.\n- `schema`: A map where keys are field names and values are lists of validator functions.","ref":"ExEtlFramework.Validator.html#validate/2-parameters","title":"Parameters - ExEtlFramework.Validator.validate/2","type":"function"},{"doc":"Returns either:\n- `{:ok, data}` if all validations pass.\n- `{:error, field, reason}` if any validation fails.","ref":"ExEtlFramework.Validator.html#validate/2-returns","title":"Returns - ExEtlFramework.Validator.validate/2","type":"function"},{"doc":"schema = %{name: [&Validator.required/1, &Validator.type(String)]}\n    Validator.validate(%{name: \"John\"}, schema)","ref":"ExEtlFramework.Validator.html#validate/2-example","title":"Example - ExEtlFramework.Validator.validate/2","type":"function"},{"doc":"MIT License\n\nCopyright (c) 2024 David Astor\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html","title":"License","type":"extras"},{"doc":"# ExEtlFramework\n\nExEtlFramework is a powerful and flexible ETL (Extract, Transform, Load) framework built in Elixir. It simplifies the process of creating robust data processing pipelines with built-in support for validation, error handling, and performance monitoring.","ref":"readme.html","title":"Readme","type":"extras"},{"doc":"- **Modular Pipeline Structure**: Easy-to-define ETL steps using a simple DSL\n- **Flexible Data Validation**: Schema-based validation with built-in and custom validators\n- **Error Handling Strategies**: Choose between fail-fast or error collection approaches\n- **Telemetry Integration**: Built-in performance measurement and reporting\n- **Extensible**: Easy to add custom steps and validators","ref":"readme.html#features","title":"Features - Readme","type":"extras"},{"doc":"Add `ex_etl_framework` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_etl_framework, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Readme","type":"extras"},{"doc":"","ref":"readme.html#usage","title":"Usage - Readme","type":"extras"},{"doc":"Create a module for your pipeline and use the `ExEtlFramework.Pipeline` macro:\n\n```elixir\ndefmodule MyPipeline do\n  use ExEtlFramework.Pipeline\n\n  step :extract do\n    # Extraction logic\n    {:ok, %{data: [1, 2, 3]}}\n  end\n\n  step :transform do\n    # Transformation logic\n    {:ok, %{data: [2, 4, 6]}}\n  end\n\n  step :load do\n    # Loading logic\n    {:ok, %{result: \"Data loaded successfully\"}}\n  end\n\n  # Optional: Define validation for each step\n  def validate_extract(data) do\n    schema = %{\n      data: [&ExEtlFramework.Validator.required/1, &ExEtlFramework.Validator.type(List)]\n    }\n    ExEtlFramework.Validator.validate(data, schema)\n  end\nend\n```","ref":"readme.html#defining-a-pipeline","title":"Defining a Pipeline - Readme","type":"extras"},{"doc":"Execute your pipeline with optional error handling strategy:\n\n```elixir\nresult = MyPipeline.run(%{initial: \"data\"}, error_strategy: :collect_errors)\n```","ref":"readme.html#running-a-pipeline","title":"Running a Pipeline - Readme","type":"extras"},{"doc":"","ref":"readme.html#key-components","title":"Key Components - Readme","type":"extras"},{"doc":"The core module for defining and executing ETL steps. It provides:\n\n- A DSL for defining pipeline steps\n- Automatic error handling\n- Integration with the validation system","ref":"readme.html#pipeline","title":"Pipeline - Readme","type":"extras"},{"doc":"A flexible data validation system:\n\n- Define validation schemas with built-in and custom validators\n- Easy to use in pipeline steps\n- Supports complex data structures\n\nExample of a validation schema:\n\n```elixir\nschema = %{\n  name: [&ExEtlFramework.Validator.required/1, &ExEtlFramework.Validator.type(String)],\n  age: [&ExEtlFramework.Validator.type(Integer)],\n  email: [&ExEtlFramework.Validator.required/1, &custom_email_validator/1]\n}\n```","ref":"readme.html#validator","title":"Validator - Readme","type":"extras"},{"doc":"Built-in performance monitoring using Telemetry:\n\n- Automatically measures duration of pipeline runs and individual steps\n- Tracks errors in pipelines\n- Easy to integrate with your preferred monitoring solution","ref":"readme.html#telemetry-integration","title":"Telemetry Integration - Readme","type":"extras"},{"doc":"","ref":"readme.html#advanced-usage","title":"Advanced Usage - Readme","type":"extras"},{"doc":"Create custom validation functions:\n\n```elixir\ndef custom_email_validator(value) do\n  if String.contains?(value, \"@\") do\n    :ok\n  else\n    {:error, \"Invalid email format\"}\n  end\nend\n```","ref":"readme.html#custom-validators","title":"Custom Validators - Readme","type":"extras"},{"doc":"Choose between two error handling strategies:\n\n- `:fail_fast`: Stops the pipeline at the first error\n- `:collect_errors`: Continues processing and collects all errors","ref":"readme.html#error-handling-strategies","title":"Error Handling Strategies - Readme","type":"extras"},{"doc":"Contributions are welcome! Please feel free to submit a Pull Request.","ref":"readme.html#contributing","title":"Contributing - Readme","type":"extras"},{"doc":"This project is licensed under the MIT License.","ref":"readme.html#license","title":"License - Readme","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}